pub struct Snapshot {Show 13 fields
pub schema_version: String,
pub generated_at: DateTime<Utc>,
pub command: String,
pub workspace: String,
pub target: String,
pub plugin: String,
pub config_file: Option<String>,
pub versions: BTreeMap<String, String>,
pub roots: BTreeMap<String, String>,
pub git: Option<GitInfo>,
pub timings: Vec<StageTime>,
pub graphs: BTreeMap<String, LevelGraph>,
pub presets: Vec<Preset>,
}Fields
schema_version: Stringgenerated_at: DateTime<Utc>command: Stringworkspace: StringDirectory from which code-ranker was invoked.
target: StringThe analyzed project directory (absolute path, stored once here).
plugin: Stringconfig_file: Option<String>Config file used for this analysis, if any was found.
versions: BTreeMap<String, String>roots: BTreeMap<String, String>Named system roots used to shorten node paths (e.g. {registry}).
git: Option<GitInfo>timings: Vec<StageTime>graphs: BTreeMap<String, LevelGraph>Analysis levels, keyed by level name. Today only "files" is produced.
presets: Vec<Preset>Prompt-Generator presets (refactoring principles), language-adapted.
Implementations
Sourceimpl Snapshot
impl Snapshot
pub fn new( command: String, workspace: String, target: String, plugin: String, config_file: Option<String>, versions: BTreeMap<String, String>, roots: BTreeMap<String, String>, git: Option<GitInfo>, timings: Vec<StageTime>, graphs: BTreeMap<String, LevelGraph>, presets: Vec<Preset>, ) -> Self